@@ -229,9 +229,9 @@ class CloudStackProvider(object):
             x+=1
 
         databasesinfraattr = DatabaseInfraAttr.objects.filter(databaseinfra=databaseinfra)
-        databasesinfraattr[0].is_write = True
-        databasesinfraattr[0].save()
-
+        infraattr0 = databasesinfraattr[0]
+        infraattr0.is_write = True
+        infraattr0.save()
         contextdict = {
             'EXPORTPATH': None,
             'SERVERID': None,
@@ -242,6 +242,8 @@ class CloudStackProvider(object):
             'MASTERPAIRNAME': name[0:20],
             'HOST01': instances[0].hostname,
             'HOST02': instances[1].hostname,
+            'INSTANCE01': instances[0],
+            'INSTANCE02': instances[1],
             'SECOND_SCRIPT_FILE': '/opt/dbaas/scripts/dbaas_second_script.sh',
         }
 
@@ -252,16 +254,16 @@ class CloudStackProvider(object):
             self.build_dependencies(contextdict=contextdict, host=contextdict['HOST02'], serverid=2, master=contextdict['HOST01'], 
                                          environment=environment, plan=plan, databaseinfra=databaseinfra, api=api)
 
-            self.run_script(contextdict['HOST01'], contextdict['SECOND_SCRIPT_FILE'])
-            self.run_script(contextdict['HOST02'], contextdict['SECOND_SCRIPT_FILE'])
+            #self.run_script(contextdict['HOST01'], contextdict['SECOND_SCRIPT_FILE'])
+            #self.run_script(contextdict['HOST02'], contextdict['SECOND_SCRIPT_FILE'])
             
-            #if self.run_script(contextdict['HOST01'].hostname, contextdict['SECOND_SCRIPT_FILE'])==0:
-            #    if self.run_script(contextdict['HOST02'].hostname, contextdict['SECOND_SCRIPT_FILE'])==0:
-            #        pass
-            #    else:
-            #        raise Exception, "We could not run the script on host 2"
-            #else:
-            #        raise Exception, "We could not run the script on host 1"
+            if self.run_script(contextdict['HOST01'], contextdict['SECOND_SCRIPT_FILE'])==0:
+                if self.run_script(contextdict['HOST02'], contextdict['SECOND_SCRIPT_FILE'])==0:
+                    pass
+                else:
+                    raise Exception, "We could not run the script on host 2"
+            else:
+                raise Exception, "We could not run the script on host 1"
         except Exception, e:
             for instance in instances:
                 LOG.warning("We could not deploy your cluster because: %s" % e)
@@ -302,8 +304,8 @@ class CloudStackProvider(object):
         flipper.create_flipper_dependencies(masterpairname= contextdict['MASTERPAIRNAME'], 
                                                                 readip= contextdict['IPREAD'], 
                                                                 writeip= contextdict['IPWRITE'], 
-                                                                instance1= contextdict['HOST01'], 
-                                                                instance2= contextdict['HOST02'], 
+                                                                hostname1= contextdict['HOST01'].hostname, 
+                                                                hostname2= contextdict['HOST02'].hostname, 
                                                                 environment= environment)
 
     @classmethod
@@ -333,14 +335,15 @@ class CloudStackProvider(object):
                 self.build_flipper(contextdict= contextdict, environment= environment)
 
             #databaseinfra.endpoint = writeip + ":%i" %(3306)
-            databaseinfra.endpoint = contextdict['HOST01'].hostname.hostname + ":%i" %(3306)
+            #databaseinfra.endpoint = contextdict['HOST01'].hostname + ":%i" %(3306)
+            databaseinfra.endpoint = contextdict['IPWRITE'] + ":%i" %(3306)
             databaseinfra.save()
             
-            contextdict['HOST01'].databaseinfra = databaseinfra
-            contextdict['HOST01'].save()
+            contextdict['INSTANCE01'].databaseinfra = databaseinfra
+            contextdict['INSTANCE01'].save()
 
-            contextdict['HOST02'].databaseinfra = databaseinfra
-            contextdict['HOST02'].save()
+            contextdict['INSTANCE02'].databaseinfra = databaseinfra
+            contextdict['INSTANCE02'].save()
 
             LOG.info("Instance created!")
             
@@ -382,6 +385,20 @@ class CloudStackProvider(object):
         LOG.info("Instance created!")
         
         return databaseinfra
+
+    @classmethod
+    def reserve_ip(self, project_id, host_attr, api):
+        request = {'projectid': '%s' % (project_id), 'id':'%s' % (host_attr.vm_id) }
+        response = api.listVirtualMachines('GET',request)
+        nicid = response['virtualmachine'][0]['nic'][0]['id']
+        api.addIpToNic('GET', {'nicid': nicid})
+
+        sleep(20)    
+        request['virtualmachineid'] = host_attr.vm_id
+        response = api.listNics('GET',request)
+        secondary_ip = response['nic'][0]['secondaryip'][0]['ipaddress']
+        LOG.info('Secondary ip %s do host %s' % (secondary_ip, host_attr.host))
+        return secondary_ip
             
         
 
@@ -435,36 +452,14 @@ class CloudStackProvider(object):
             ssh_ok = self.check_ssh(host)
             
             if  ssh_ok:
-                if cluster:
-                    request = {'projectid': '%s' % (project_id), 'id':'%s' % (host_attr.vm_id) }
-                    response = api.listVirtualMachines('GET',request)
-                    nicid = response['virtualmachine'][0]['nic'][0]['id']
-                    api.addIpToNic('GET', {'nicid': nicid})
-                    
-                    sleep(20)    
-                    request['virtualmachineid'] = host_attr.vm_id
-                    response = api.listNics('GET',request)
-                    secondary_ip = response['nic'][0]['secondaryip'][0]['ipaddress']
-                    LOG.info('Secondary ip %s do host %s' % (secondary_ip, host_attr.host))
-                    
+                if cluster:                    
                     databaseinfraattr = DatabaseInfraAttr()
-                    databaseinfraattr.ip = secondary_ip
+                    databaseinfraattr.ip = self.reserve_ip(project_id= project_id, host_attr= host_attr, api= api)
                     databaseinfraattr.databaseinfra = databaseinfra
                     databaseinfraattr.save()
                 else:
-                    disk = StorageManager.create_disk(environment=environment, plan=plan, host=host)
-                    context = Context({"EXPORTPATH": disk['path']})
-            
-                    template = Template(planattr.userdata)
-                    userdata = template.render(context)
-                            
-                    request = {'id': host_attr.vm_id, 'userdata': b64encode(userdata)}
-                    response = api.updateVirtualMachine('POST', request)
-                
-                    self.run_script(host, "/opt/dbaas/scripts/dbaas_userdata_script.sh")
-
-                    LOG.info("Host %s is ready!" % (host.hostname))
-                
+                    disk = self.build_nfsaas(environment=environment, plan=plan, host=host)
+                    self.update_userdata(host= host, api= api, plan= plan, contextdict={"EXPORTPATH": disk['path']})
                 return instance
             else:
                 raise Exception, "Maximum number of login attempts!"
